import io

import matplotlib
import matplotlib.pyplot as plt
from matplotlib import dates as mdates
from django.contrib.auth.decorators import login_required
from django.http import HttpResponse
from django.utils.translation import gettext as _

from main.models import (
    Transaction,
    Invoice,
    Category,
    Snapshot,
)


matplotlib.use("Agg")
plt.style.use("./plot/nummi.mplstyle")


@login_required
def timeline(request):
    _snapshots = Snapshot.objects.all()

    fig, ax = plt.subplots()
    ax.step(
        [s.date for s in _snapshots],
        [s.value for s in _snapshots],
        where="post",
    )
    ax.set(ylabel=_("Snapshots"), ylim=0)
    ax.xaxis.set_major_formatter(
        mdates.ConciseDateFormatter(ax.xaxis.get_major_locator())
    )
    _io = io.StringIO()

    fig.savefig(_io, format="svg")

    return HttpResponse(_io.getvalue(), headers={"Content-Type": "image/svg+xml"})
